#
# Makefile Template for Tessy
# Compiler   : ANSI-C/cC++ Compiler for HC08
# Environment: Codewarrior 10 (Freescale Semiconductor, Inc.)
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
METROWERKS_HOME := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
MODULE_PATH_DOS := $(shell ts_pathname -w '$(MODULE_PATH_DOS)')

TS_NAME         := TS_CODEWARRIOR
IDE_NAME        := codewarrior10
COMPANY_NAME    := metrowerks
PROCESSOR_NAME  := hcs08

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
  TS_BYTEORDER_OPTION :=
  TS_BYTEORDER_LOPTION :=
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION :=
  TS_BYTEORDER_LOPTION :=
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all    : master slave
master : $(MODULE_PATH)\ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)


#

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#
S_CC           := $(METROWERKS_HOME)\prog\chc08.exe
S_LINK         := $(METROWERKS_HOME)\prog\linker.exe
S_INCLUDES     := -M$(MEMORY_MODEL) -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS) \
                  -I"$(METROWERKS_HOME)/lib/hc08c/device/src" \
                  -I"$(METROWERKS_HOME)/lib/hc08c/lib" -I"$(METROWERKS_HOME)/lib/hc08c/src" \
                  -I"$(METROWERKS_HOME)/lib/hc08c/device/include" -I"$(METROWERKS_HOME)/lib/hc08c/include" \
                  -I"$(METROWERKS_HOME)/lib/hc08c/device/asm_include"
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)
S_COMP_OPTIONS := -O0 -BfaTSRON -Qvtpnone -F2 -ViewHidden \
                  -MMU -Cs08 -LmCfg=xilmou -DTESSY -DTS_SLAVE -DTS_HC08
ifeq ($(MEMORY_MODEL),s)
S_COMP_OPTIONS += -TD2 -Fd
endif
ifeq ($(MEMORY_MODEL),b)
S_COMP_OPTIONS += -DTS_HAVE_FLOAT64
endif
S_LINK_OPTIONS := -O0 -M -ViewHidden

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -ObjN="$@" "$<" -Lm="$(@:$(OBJFILE_EXTENSION)=.d)"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -ObjN="$@"

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -ObjN="$@"


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -ObjN="$@"

ifeq ("true","$(USE_BOARD_FILES)")
ifeq ("","$(INITOBJDIR)")
$(error Attribute 'Use Board Files' is set to true but 'InitObjDir' is empty.)
endif
ifeq ("","$(INITSRCDIR)")
$(error Attribute 'Use Board Files' is set to true but 'InitSrcDir' is empty.)
endif
HCS08_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
                 $(patsubst $(INITSRCDIR)/%.asm,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.asm))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) $(S_INCLUDES) -I$(INITSRCDIR) $(S_COMP_OPTIONS) $< -ObjN="$@"

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.asm
	$(S_CC) $(S_INCLUDES) -I$(INITSRCDIR) $(S_COMP_OPTIONS) $< -ObjN="$@"
endif


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
																			$(S_SRC_OBJECTS) \
																			$(HCS08_OBJS) \
																			$(S_UC_OBJECT) \
																			$(S_STUB_OBJECT) \
																			$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(USER_LINK_OPTIONS) $(S_LINK_OPTIONS) \
						-Add($(S_OBJECTS) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
						$(S_SRC_OBJECTS) $(HCS08_OBJS) $(S_UC_OBJECT) $(S_STUB_OBJECT) "$(LIBRARY)") \
						"$(LINKER_FILE)" -O"$@"
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)

#####################################################################
#END_TARGETS
#####################################################################
